==> vue-color-picker-2.8.0.tgz: package/lib/pc.js <==
import { renderless, api } from "@dftvue2-opentiny/vue-renderless/color-picker/vue";
import { defineComponent, props, setup as _setup } from "@dftvue2-opentiny/vue-common";
import { IconChevronDown } from "@dftvue2-opentiny/vue-icon";
import ColorSelectPanel from "@dftvue2-opentiny/vue-color-select-panel";
import "@dftvue2-opentiny/vue-theme/color-picker/index.css";
function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  if (functionalTemplate) {
    options.functional = true;
  }
  if (scopeId) {
    options._scopeId = "data-v-" + scopeId;
  }
  var hook;
  if (moduleIdentifier) {
    hook = function hook2(context) {
      context = context || // cached call
      this.$vnode && this.$vnode.ssrContext || // stateful
      this.parent && this.parent.$vnode && this.parent.$vnode.ssrContext;
      if (!context && typeof __VUE_SSR_CONTEXT__ !== "undefined") {
        context = __VUE_SSR_CONTEXT__;
      }
      if (injectStyles) {
        injectStyles.call(this, context);
      }
      if (context && context._registeredComponents) {
        context._registeredComponents.add(moduleIdentifier);
      }
    };
    options._ssrRegister = hook;
  } else if (injectStyles) {
    hook = shadowMode ? function() {
      injectStyles.call(this, (options.functional ? this.parent : this).$root.$options.shadowRoot);
    } : injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var render = function render2() {
  var _vm$state$triggerBg;
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("div", {
    directives: [{
      name: "clickoutside",
      rawName: "v-clickoutside",
      value: _vm.onCancel,
      expression: "onCancel"
    }],
    staticClass: "tiny-color-picker__trigger",
    on: {
      "click": function click() {
        return _vm.changeVisible(!_vm.state.isShow);
      }
    }
  }, [_c("div", {
    staticClass: "tiny-color-picker__inner",
    style: {
      background: (_vm$state$triggerBg = _vm.state.triggerBg) !== null && _vm$state$triggerBg !== void 0 ? _vm$state$triggerBg : ""
    }
  }, [_c("IconChevronDown")], 1), _c("Transition", {
    attrs: {
      "name": "tiny-zoom-in-top"
    }
  }, [_c("color-select", {
    attrs: {
      "visible": _vm.state.isShow,
      "alpha": _vm.alpha
    },
    on: {
      "confirm": _vm.onConfirm,
      "cancel": _vm.onCancel,
      "hue-update": _vm.onHueUpdate,
      "sv-update": _vm.onSVUpdate
    },
    model: {
      value: _vm.state.hex,
      callback: function callback($$v) {
        _vm.$set(_vm.state, "hex", $$v);
      },
      expression: "state.hex"
    }
  })], 1)], 1);
};
var staticRenderFns = [];
var __vue2_script = defineComponent({
  emits: ["update:modelValue", "confirm", "cancel"],
  props: [].concat(props, ["modelValue", "visible", "alpha"]),
  components: {
    IconChevronDown: IconChevronDown(),
    ColorSelect: ColorSelectPanel
  },
  setup: function setup(props2, context) {
    return _setup({
      props: props2,
      context,
      renderless,
      api
    });
  }
});
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles, null, null, null);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var pc = /* @__PURE__ */ function() {
  return __component__.exports;
}();
export {
  pc as default
};

==> vue-color-picker-2.21.0.tgz: package/lib/pc.js <==
import { renderless, api } from '@opentinyvue/vue-renderless/color-picker/vue';
import { defineComponent, props, setup } from '@opentinyvue/vue-common';
import { IconChevronDown } from '@opentinyvue/vue-icon';
import ColorSelectPanel from '@opentinyvue/vue-color-select-panel';
import '@opentinyvue/vue-theme/color-picker/index.css';

function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  var hook;
  if (injectStyles) {
    hook = injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var render = function render2() {
  var _vm$state$hex;
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("div", {
    class: [{
      "tiny-color-picker": true
    }, _vm.state.size ? "tiny-color-picker--" + _vm.state.size : ""],
    on: {
      "click": function click() {
        return _vm.changeVisible(!_vm.state.isShow);
      }
    }
  }, [_c("div", {
    staticClass: "tiny-color-picker__inner",
    style: {
      background: (_vm$state$hex = _vm.state.hex) !== null && _vm$state$hex !== void 0 ? _vm$state$hex : ""
    }
  }, [_c("IconChevronDown")], 1), _c("Transition", {
    attrs: {
      "name": "tiny-zoom-in-top"
    }
  }, [_c("color-select", {
    style: {
      "min-width": "420px"
    },
    attrs: {
      "visible": _vm.state.isShow,
      "alpha": _vm.alpha,
      "predefine": _vm.state.predefineStack,
      "history": _vm.state.stack,
      "format": _vm.format,
      "enable-history": _vm.state.enableHistory,
      "enable-predefine-color": _vm.state.enablePredefineColor
    },
    on: {
      "confirm": _vm.onConfirm,
      "cancel": _vm.onCancel
    },
    model: {
      value: _vm.state.hex,
      callback: function callback($$v) {
        _vm.$set(_vm.state, "hex", $$v);
      },
      expression: "state.hex"
    }
  })], 1)], 1);
};
var staticRenderFns = [];
var __vue2_script = defineComponent({
  emits: ["update:modelValue", "confirm", "cancel"],
  props: [].concat(props, ["modelValue", "visible", "alpha", "predefine", "history", "size", "format", "enableHistory", "enablePredefineColor"]),
  components: {
    IconChevronDown: IconChevronDown(),
    ColorSelect: ColorSelectPanel
  },
  setup: function setup$1(props2, context) {
    return setup({
      props: props2,
      context,
      renderless,
      api
    });
  }
});
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var pc = /* @__PURE__ */ function() {
  return __component__.exports;
}();

export { pc as default };
